@@ -16,12 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+
+
 #ifndef ADDMULT_H
 #define ADDMULT_H
 
 int addmult( void);
 int addmult2( void);
-int load_multipliers(void);
+int init_and_load_multipliers(void);
 int remember_multi(char *multiplier, int band, int show_new_band);
 void init_mults();
 
