@@ -141,7 +141,6 @@ char callinput(void)
     extern int k_pin14;
     extern int k_ptt;
     extern int noautocq;
-    extern int keyerport;
     extern int miniterm;
     extern int no_rst;
 
@@ -190,10 +189,8 @@ char callinput(void)
 
 	    time_update();
 
-	    if (trxmode == DIGIMODE && (keyerport == GMFSK
-		    || keyerport == MFJ1278_KEYER)) {
+	    if (trxmode == DIGIMODE) {
 		show_rtty();
-		printcall();
 	    }
 
 	    /* if BMAUTOADD is active and user has input a call sign
@@ -1233,12 +1230,6 @@ char callinput(void)
 	    break;
 	}
 
-	if (trxmode == DIGIMODE && (keyerport == GMFSK
-		|| keyerport == MFJ1278_KEYER)) {
-	    show_rtty();
-	    refreshp();
-	}
-
     }
 
     return (x);
@@ -1379,6 +1370,7 @@ int play_file(char *audiofile)
 {
 
     extern int txdelay;
+    extern unsigned char rigptt;
 
     int fd,rc;
     char playcommand[120];
@@ -1396,11 +1388,36 @@ int play_file(char *audiofile)
 	else {
 	   sprintf( playcommand, "play_vk %s", audiofile);
 	}
+#ifdef HAVE_LIBHAMLIB
+	/* CAT PTT wanted and available, use it. */
+	if (rigptt == 0x03) {
+	    /* Request PTT On */
+	    rigptt |= (1 << 3);		/* 0x0b */
+	}
+	else {		/* Fall back to netkeyer interface */
+#endif
 	netkeyer(K_PTT, "1");	// ptt on
+#ifdef HAVE_LIBHAMLIB
+	}
+#endif
+
 	usleep(txdelay * 1000);
 	rc=system(playcommand);
 	printcall();
+
+#ifdef HAVE_LIBHAMLIB
+	/* CAT PTT wanted, available, and active. */
+	if (rigptt == 0x07) {
+
+	    /* Request PTT Off */
+	    rigptt |= (1 << 4);		/* 0x17 */
+	}
+	else {		/* Fall back to netkeyer interface */
+#endif
 	netkeyer(K_PTT, "0");	// ptt off
+#ifdef HAVE_LIBHAMLIB
+	}
+#endif
     }
 
     return (0);
