@@ -52,7 +52,7 @@ int gettxinfo(void)
     extern int cw_bandwidth;
     extern int trxmode;
     extern int rigmode;
-    extern int keyerport;
+    extern int digikeyer;
 #else
     extern int outfreq;
 #endif
@@ -61,6 +61,7 @@ int gettxinfo(void)
     extern float bandfrequency[];
 
     extern int trx_control;
+    extern unsigned char rigptt;
 
 #ifdef HAVE_LIBHAMLIB
     freq_t rigfreq;
@@ -73,12 +74,42 @@ int gettxinfo(void)
 #endif
 
     static int oldbandinx;
+    static int fldigi_carrier;
+    static int fldigi_shift_freq;
 
     void send_bandswitch(int freq);
 
     if (trx_control != 1)
 	return (0);
 
+#ifdef HAVE_LIBHAMLIB
+    /* CAT PTT wanted, available, inactive, and PTT On requested
+     * bits 0, 1, and 3 set.
+     */
+    if (rigptt == 0x0b) {
+	retval = rig_set_ptt(my_rig, RIG_VFO_CURR, RIG_PTT_ON);
+
+	/* Set PTT active bit. */
+	rigptt |= (1 << 2);		/* 0x0f */
+
+	/* Clear PTT On requested bit. */
+	rigptt &= ~(1 << 3);		/* 0x07 */
+    }
+
+    /* CAT PTT wanted, available, active and PTT Off requested
+     * bits 0, 1, 2, and 4 set.
+     */
+    if (rigptt == 0x17) {
+	retval = rig_set_ptt(my_rig, RIG_VFO_CURR, RIG_PTT_OFF);
+
+	/* Clear PTT Off requested bit. */
+	rigptt &= ~(1 << 4);		/* 0x07 */
+
+	/* Clear PTT active bit. */
+	rigptt &= ~(1 << 2);		/* 0x03 */
+    }
+#endif
+
     if (outfreq == 0) {
 
 	rigfreq = 0.0;
@@ -87,7 +118,8 @@ int gettxinfo(void)
 	retval = rig_get_vfo(my_rig, &vfo); /* initialize RIG_VFO_CURR */
 	if (retval == RIG_OK || retval == -RIG_ENIMPL || retval == -RIG_ENAVAIL) {
 	    retval = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);
-	    if (trxmode == DIGIMODE && keyerport == GMFSK && retval == RIG_OK) {
+	    if (trxmode == DIGIMODE && (digikeyer == GMFSK || digikeyer == FLDIGI)
+			&& retval == RIG_OK) {
 		retvalmode = rig_get_mode(my_rig, RIG_VFO_CURR, (rmode_t *)&rigmode, &bwidth);
 		if (retvalmode != RIG_OK) {
 		    rigmode = RIG_MODE_NONE;
@@ -95,8 +127,15 @@ int gettxinfo(void)
 	    }
 	}
 
-	if (trxmode == DIGIMODE && keyerport == GMFSK) {
-	    rigfreq += fldigi_get_carrier();
+	if (trxmode == DIGIMODE && (digikeyer == GMFSK || digikeyer == FLDIGI)) {
+	    fldigi_carrier = fldigi_get_carrier();
+	    rigfreq += (freq_t)fldigi_carrier;
+	    if (rigmode == RIG_MODE_RTTY || rigmode == RIG_MODE_RTTYR) {
+		fldigi_shift_freq = fldigi_get_shift_freq();
+		if (fldigi_shift_freq != 0) {
+		    retval = rig_set_freq(my_rig, RIG_VFO_CURR, ((freq_t)rigfreq + (freq_t)fldigi_shift_freq));
+		}
+	    }
 	}
 
 	if (retval != RIG_OK || rigfreq < 0.1) {
@@ -182,15 +221,17 @@ int gettxinfo(void)
 		    sleep(1);
 		}
 	    } else if (trxmode == DIGIMODE) {
-		retval =
-		    rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_LSB,
+                if ((rigmode & (RIG_MODE_LSB | RIG_MODE_USB | RIG_MODE_RTTY | RIG_MODE_RTTYR)) != rigmode) {
+		    retval =
+		    	rig_set_mode(my_rig, RIG_VFO_CURR, RIG_MODE_LSB,
 				 TLF_DEFAULT_PASSBAND);
 
-		if (retval != RIG_OK) {
-		    mvprintw(24, 0,
+		    if (retval != RIG_OK) {
+			mvprintw(24, 0,
 			     "Problem with rig link: set mode!\n");
-		    refreshp();
-		    sleep(1);
+			refreshp();
+		    	sleep(1);
+                    }
 		}
 
 	    } else {
