@@ -37,6 +37,7 @@
 #include "tlf.h"
 #include "tlf_panel.h"
 #include "ui_utils.h"
+#include "write_keyer.h"
 
 /* size and position of keyer window */
 #define KEYER_LINE_WIDTH 60
@@ -54,9 +55,9 @@ int keyer(void)
     extern int cqmode;
     extern char mode[20];
     extern char message[][80];
-    extern char wkeyerbuffer[];
-    extern int data_ready;
-    extern int keyerport;
+    extern int trxmode;
+    extern int cwkeyer;
+    extern int digikeyer;
     extern int weight;
 
     WINDOW *win = NULL;
@@ -73,7 +74,8 @@ int keyer(void)
     const char crcontrolstring[2] = { 13, '\0' };	// cr
     const char ctl_c_controlstring[2] = { 92, '\0' };	// '\'
 
-    if (keyerport == NO_KEYER)	/* no keyer present */
+    if ((trxmode == CWMODE && cwkeyer == NO_KEYER) ||
+	(trxmode == DIGIMODE && digikeyer == NO_KEYER)) /* no keyer present */
 	return 1;
 
     strcpy(mode, "Keyboard");
@@ -95,11 +97,9 @@ int keyer(void)
     werase(win);
     wnicebox(win, 0, 0, 1, KEYER_LINE_WIDTH, "CW Keyer");
 
-    if (keyerport == MFJ1278_KEYER) {
-	if (data_ready != 1) { 		/* switch to tx */
-	    strcat(wkeyerbuffer, txcontrolstring);
-	    data_ready = 1;
-	}
+    if (cwkeyer == MFJ1278_KEYER || digikeyer == MFJ1278_KEYER) {
+	/* switch to tx */
+	keyer_append(txcontrolstring);
     }
 
     while (1) {
@@ -124,11 +124,9 @@ int keyer(void)
 
 	// <Escape>, Ctrl-K (^K), Alt-k (M-k)
 	if (x == 27 || x == 11 || x == 235) {
-	    if (keyerport == MFJ1278_KEYER) {
-		if (data_ready != 1) { 	/* switch back to rx */
-		    strcat(wkeyerbuffer, rxcontrolstring);
-		    data_ready = 1;
-		}
+	    if (cwkeyer == MFJ1278_KEYER || digikeyer == MFJ1278_KEYER) {
+		/* switch back to rx */
+		keyer_append(rxcontrolstring);
 	    } else {
 		stoptx();
 	    }
@@ -142,12 +140,12 @@ int keyer(void)
 
 	if (x > 9 && x < 91) { 	/* drop all other control char... */
 	    if (x > 31 || x == 10) {
-		if (keyerport == MFJ1278_KEYER) {
+		if (cwkeyer == MFJ1278_KEYER || digikeyer == MFJ1278_KEYER) {
 		    mfj1278_control(x);
-		} else if (keyerport == NET_KEYER) {
+		} else if (cwkeyer == NET_KEYER) {
 		    nkbuffer[0] = x;	// 1 char at the time !
 		    nkbuffer[1] = '\0';
-		    netkeyer(K_MESSAGE, nkbuffer);
+		    keyer_append(nkbuffer);
 		}
 
 		/* if display field is full move text one left */
@@ -168,7 +166,8 @@ int keyer(void)
 	    case 13:
 	    case KEY_ENTER:
 		{
-		    if (keyerport == MFJ1278_KEYER) {
+		    if (cwkeyer == MFJ1278_KEYER ||
+			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(crcontrolstring);
 		    }
 		    break;
@@ -176,21 +175,24 @@ int keyer(void)
 
 	    case 123:		/* { */
 		{
-		    if (keyerport == MFJ1278_KEYER) {
+		    if (cwkeyer == MFJ1278_KEYER ||
+			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(txcontrolstring);
 		    }
 		    break;
 		}
 	    case 125:		/* } */
 		{
-		    if (keyerport == MFJ1278_KEYER) {
+		    if (cwkeyer == MFJ1278_KEYER ||
+			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(rxcontrolstring);
 		    }
 		    break;
 		}
 	    case 92:		/* \ */
 		{
-		    if (keyerport == MFJ1278_KEYER) {
+		    if (cwkeyer == MFJ1278_KEYER ||
+			    digikeyer == MFJ1278_KEYER) {
 			sendmessage(ctl_c_controlstring);
 		    }
 		    break;
@@ -315,8 +317,6 @@ int keyer(void)
 void mfj1278_control(int x)
 {
     extern int trxmode;
-    extern char wkeyerbuffer[];
-    extern int data_ready;
 
     char buffer[2];
 
@@ -328,10 +328,6 @@ void mfj1278_control(int x)
 	}
 	buffer[0] = x;		// 1 char at the time !
 	buffer[1] = '\0';
-	if (data_ready != 1) {
-	    strcat(wkeyerbuffer, buffer);
-	    data_ready = 1;
-	}
-	buffer[0] = '\0';
+	keyer_append(buffer);
     }
 }
