@@ -69,18 +69,12 @@
 
 
 SCREEN *mainscreen;
-SCREEN *packetscreen;
-WINDOW *sclwin, *entwin;
 
 extern int lan_active;
 
-int prsock = 0;
 char pr_hostaddress[48] = "131.155.192.179";
 char *config_file = NULL;
 int portnum = 0;
-struct tln_logline *loghead = NULL;
-struct tln_logline *logtail = NULL;
-struct tln_logline *viewing = NULL;
 
 int use_rxvt = 0;
 int use_xterm = 0;
@@ -96,7 +90,6 @@ int tlfcolors[8][2] = { {COLOR_BLACK, COLOR_WHITE},
 };
 int debugflag = 0;
 int editor = EDITOR_JOE;
-char rttyoutput[120];
 int tune_val = 0;
 int use_bandoutput = 0;
 int no_arrows = 0;
@@ -114,6 +107,9 @@ int arrlss = 0;
 int pacc_pa_flg = 0;
 int stewperry_flg = 0;
 int focm = 0;
+int sprint_mode = 0;
+int minitest = 0;	/**< if set, length of minitest period in seconds */
+int unique_call_multi = 0;          /* do we count calls as multiplier */
 
 int universal = 0;
 int addcallarea;
@@ -188,14 +184,16 @@ char multsfile[80] = "";	/* name of file with a list of allowed
 				   multipliers */
 char exchange_list[40] = "";
 int timeoffset = 0;
-int multi = 0;			/* 0 = SO , 1 = MOST, 2 = MM */
 int trxmode = CWMODE;
 int rigmode = 0;		/* RIG_MODE_NONE in hamlib/rig.h, but if hamlib not compiled, then no dependecy */
 int mixedmode = 0;
 char his_rst[4] = "599";
 char my_rst[4] = "599";
 char last_rst[4] = "599";       /* Report for last QSO */
+
+/* TODO Maybe we can use the following */
 int mults_per_band = 1;		/* mults count per band */
+
 int shortqsonr = LONGCW;	/* 1  =  short  cw char in exchange */
 int cluster = NOCLUSTER;	/* 0 = OFF, 1 = FOLLOW, 2  = spots  3 = all */
 int clusterlog = 0;		/* clusterlog on/off */
@@ -212,10 +210,18 @@ char whichcontest[40] = "qso";
 int defer_store = 0;
 char call[20];
 char logfile[120] = "general.log";
-char *cabrillo = NULL;		/*< Name of the cabrillo format definition */
+char *cabrillo = NULL;		/**< Name of the cabrillo format definition */
 char synclogfile[120];
 char markerfile[120] = "";
 int xplanet = 0;
+unsigned char rigptt = 0;
+	/**< Bitmask for Hamlib CAT PTT
+	 * bit 0 set: CAT PTT wanted--RIGPTT in logcfg.dat (set in parse_logcfg)
+	 * bit 1 set: CAT PTT available--from rig caps (set in sendqrg)
+	 * bit 2 set: PTT active (set/unset in gettxinfo)
+	 * bit 3 set: PTT On (set/unset in callinput)
+	 * bit 4 set: PTT Off (set/unset in callinput)
+	 */
 
 char sp_return[80] = " \n";
 char cq_return[80] = " \n";
@@ -305,19 +311,23 @@ int scale_values[20] =
 char sc_device[40] = "/dev/dsp";
 
 /*-------------------------------------keyer------------------------------*/
-int keyerport = NO_KEYER;
+int cwkeyer = NO_KEYER;
+int digikeyer = NO_KEYER;
+
+char keyer_device[10] = "";	// ttyS0, ttyS1, lp0-2 for net_keyer
+
+char controllerport[80] = "/dev/ttyS0"; // for GMFSK or MFJ-1278
+char rttyoutput[120];		// where to GMFSK digimode output
+
 int txdelay = 0;
 int weight = 0;
 char weightbuf[4];
 char tonestr[5] = "600";
 int cqdelay = 8;
-char wkeyerbuffer[400];
-int data_ready = 0;
-char keyer_device[10] = "";	// ttyS0, ttyS1, lp0-2
 int k_tune;
 int k_pin14;
 int k_ptt;
-char controllerport[80] = "/dev/ttyS0";
+
 int miniterm = 0;		/* is miniterm for digimode active? */
 char modem_mode[8];
 int commentfield = 0;		/* 1 if we are in comment/excahnge input */
@@ -328,11 +338,9 @@ int nr_of_spots;			/* Anzahl Lines in spot_ptr array */
 char lastwwv[120] = "";
 int packetinterface = 0;
 int fdSertnc = 0;
-int fdFIFO = 0;
 int tncport = 1;
 char tncportname[40];
 char rigconf[80];
-int in_packetclient;
 int tnc_serial_rate = 2400;
 char clusterlogin[80] = "";
 int bmautoadd = 0;
@@ -358,6 +366,9 @@ int rignumber = 0;
 int rig_comm_error = 0;
 int rig_comm_success = 0;
 
+/*----------------------------------fldigi---------------------------------*/
+char fldigi_url[50] = "http://localhost:7362/RPC2";
+
 /*---------------------------------simulator-------------------------------*/
 int simulator = 0;
 int simulator_mode = 0;
@@ -371,8 +382,8 @@ char qsos[MAX_QSOS][LOGLINELEN+1];
 int nr_qsos = 0;
 
 /*------------------------------dupe array---------------------------------*/
-int nr_worked = 0;		/*< number of calls in worked[] */
-struct worked_t worked[MAX_CALLS]; /*< worked stations */
+int nr_worked = 0;		/**< number of calls in worked[] */
+struct worked_t worked[MAX_CALLS]; /**< worked stations */
 
 /*----------------------statistic of worked countries,zones ... -----------*/
 int countries[MAX_DATALINES];	/* per country bit fieldwith worked bands set */
@@ -744,6 +755,19 @@ void hamlib_init()
 #endif				/* HAVE_LIBHAMLIB */
 }
 
+void fldigi_init() {
+#ifdef HAVE_LIBXMLRPC
+    int status;
+
+    if (digikeyer == FLDIGI) {
+	xmlrpc_showinfo();
+	status = fldigi_xmlrpc_init();
+	if (status != 0) {
+	    digikeyer = NO_KEYER;
+	}
+    }
+#endif
+}
 
 void lan_init()
 {
@@ -784,8 +808,8 @@ void keyer_init()
 {
     char keyerbuff[3];
 
-    if (keyerport == NET_KEYER) {
-	showmsg("Keyer is cwdaemon");
+    if (cwkeyer == NET_KEYER) {
+	showmsg("CW-Keyer is cwdaemon");
 
 	if (netkeyer_init() < 0) {
 	    showmsg("Cannot open NET keyer daemon ");
@@ -819,7 +843,8 @@ void keyer_init()
 
     }
 
-    if (keyerport == MFJ1278_KEYER || keyerport == GMFSK) {
+    if (cwkeyer == MFJ1278_KEYER || digikeyer == MFJ1278_KEYER ||
+	    digikeyer == GMFSK) {
 	init_controller();
     }
 
@@ -842,7 +867,7 @@ void tlf_cleanup()
 //    commented out for the moment as it will segfault if called twice
 //    cleanup_telnet();
 
-    if (trxmode == CWMODE && keyerport == NET_KEYER)
+    if (trxmode == CWMODE && cwkeyer == NET_KEYER)
 	netkeyer_close();
     else
 	deinit_controller();
@@ -855,6 +880,12 @@ void tlf_cleanup()
 
 #endif
 
+#ifdef HAVE_LIBXMLRPC
+    if (digikeyer == FLDIGI) {
+	fldigi_xmlrpc_cleanup();
+    }
+#endif
+
     endwin();
     tcsetattr( STDIN_FILENO, TCSANOW, &oldt);
 }
@@ -911,8 +942,8 @@ int main(int argc, char *argv[])
 //              if (strlen(synclogfile) > 0)
 //                      synclog(synclogfile);
 
-    xmlrpc_showinfo();
     hamlib_init();
+    fldigi_init();
     lan_init();
     keyer_init();
 
