@@ -47,7 +47,8 @@
 #endif
 
 
-extern int keyerport;
+extern int cwkeyer;
+extern int digikeyer;
 extern char tonestr[];
 extern int partials;
 extern int use_part;
@@ -68,7 +69,7 @@ void KeywordNotSupported(char *keyword);
 void ParameterNeeded(char *keyword);
 void WrongFormat(char *keyword);
 
-#define  MAX_COMMANDS 231	/* commands in list */
+#define  MAX_COMMANDS 236	/* commands in list */
 
 
 int read_logcfg(void)
@@ -84,7 +85,8 @@ int read_logcfg(void)
     contest = 0;
     partials = 0;
     use_part = 0;
-    keyerport = 0;
+    cwkeyer = NO_KEYER;
+    digikeyer = NO_KEYER;
     portnum = 0;
     packetinterface = 0;
     tncport = 0;
@@ -169,7 +171,6 @@ int parse_logcfg(char *inputbuffer)
     extern char call[];
     extern char whichcontest[];
     extern char logfile[];
-    extern int keyerport;
     extern int recall_mult;
     extern int one_point;
     extern int two_point;
@@ -296,6 +297,11 @@ int parse_logcfg(char *inputbuffer)
     extern int pfxmultab;
     extern int bmautoadd;
     extern int bmautograb;
+    extern int sprint_mode;
+    extern char fldigi_url[50];
+    extern unsigned char rigptt;
+    extern int minitest;
+    extern int unique_call_multi;
 
     char commands[MAX_COMMANDS][30] = {
 	"enable",		/* 0 */		/* deprecated */
@@ -524,12 +530,17 @@ int parse_logcfg(char *inputbuffer)
 	"QTCREC_RECORD",
 	"QTCREC_RECORD_COMMAND",
 	"EXCLUDE_MULTILIST",
-	"S&P_CALL_MSG",
+	"S&P_CALL_MSG",		/* 225 */
 	"QTC_CAP_CALLS",
 	"QTC_AUTO_FILLTIME",
 	"BMAUTOGRAB",
 	"BMAUTOADD",
-	"QTC_RECV_LAZY"		/* 230 */
+	"QTC_RECV_LAZY",		/* 230 */
+	"SPRINTMODE",
+	"FLDIGI",
+	"RIGPTT",
+	"MINITEST",
+	"UNIQUE_CALL_MULTI"		/* 235 */
     };
 
     char **fields;
@@ -991,7 +1002,7 @@ int parse_logcfg(char *inputbuffer)
 	    break;
 	}
     case 65:{
-	    keyerport = NET_KEYER;
+	    cwkeyer = NET_KEYER;
 	    break;
 	}
     case 66:{
@@ -1377,7 +1388,8 @@ int parse_logcfg(char *inputbuffer)
 	    }
     case 140:{
 		PARAMETER_NEEDED(teststring);
-		keyerport = MFJ1278_KEYER;
+		cwkeyer = MFJ1278_KEYER;
+		digikeyer = MFJ1278_KEYER;
 		g_strlcpy(controllerport, g_strchomp(fields[1]),
 			sizeof(controllerport));
 		break;
@@ -1420,7 +1432,7 @@ int parse_logcfg(char *inputbuffer)
 	    }
     case 149:{
 		PARAMETER_NEEDED(teststring);
-		keyerport = GMFSK;
+		digikeyer = GMFSK;
 		g_strlcpy(controllerport, g_strchomp(fields[1]),
 			sizeof(controllerport));
 		break;
@@ -1749,7 +1761,7 @@ int parse_logcfg(char *inputbuffer)
     }
     case 224: {
 	    PARAMETER_NEEDED(teststring);
-	    if (strcmp(fields[1], "CONTINENTLIST")) {
+	    if (strcmp(g_strchomp(fields[1]), "CONTINENTLIST") == 0) {
 	        if (strlen(continent_multiplier_list[0]) == 0) {
 		    showmsg
 			("WARNING: you need to set the CONTINENTLIST parameter...");
@@ -1758,7 +1770,7 @@ int parse_logcfg(char *inputbuffer)
 		}
 		exclude_multilist_type = 1;
 	    }
-	    else if (strcmp(fields[1], "COUNTRYLIST")) {
+	    else if (strcmp(g_strchomp(fields[1]), "COUNTRYLIST") == 0) {
 	        if (strlen(countrylist[0]) == 0) {
 		    showmsg
 			("WARNING: you need to set the COUNTRYLIST parameter...");
@@ -1802,6 +1814,63 @@ int parse_logcfg(char *inputbuffer)
 	    qtc_recv_lazy = 1;
 	    break;
     }
+    case 231: {
+	    sprint_mode = 1;
+	    break;
+    }
+    case 232:{
+#ifndef HAVE_LIBXMLRPC
+	    showmsg ("WARNING: XMLRPC not compiled - skipping setup.");
+	    sleep(2);
+	    digikeyer = NO_KEYER;
+#else
+	    if (fields[1] != NULL) {
+		g_strlcpy(fldigi_url, g_strchomp(fields[1]),
+			sizeof(fldigi_url));
+	    }
+	    digikeyer = FLDIGI;
+#endif
+	    break;
+    }
+    case 233:{
+	    rigptt |= (1 << 0);		/* bit 0 set--CAT PTT wanted (RIGPTT) */
+	    break;
+    }
+    case 234:{
+	    if (fields[1] != NULL) {
+		int minisec;
+		minisec = atoi(g_strchomp(fields[1]));
+		if ((3600%minisec) != 0) {
+		    showmsg
+			("WARNING: invalid MINITEST value, must be an integral divider for 3600s!");
+		    sleep(5);
+		    exit(1);
+		}
+		else {
+		    minitest = minisec;
+		}
+	    }
+	    else {
+		minitest = MINITEST_DEFAULT_PERIOD;
+	    }
+	    break;
+    }
+    case 235: {
+	    PARAMETER_NEEDED(teststring);
+	    if (strcmp(g_strchomp(fields[1]), "ALL") == 0) {
+		unique_call_multi = UNIQUECALL_ALL;
+	    }
+	    else if (strcmp(g_strchomp(fields[1]), "BAND") == 0) {
+		unique_call_multi = UNIQUECALL_BAND;
+	    }
+	    else {
+		showmsg
+			("WARNING: choose one of these for UNIQUE_CALL_MULTI: ALL, BAND");
+		    sleep(5);
+		    exit(1);
+	    }
+	    break;
+    }
     default: {
 		KeywordNotSupported(g_strstrip(inputbuffer));
 		break;
