@@ -22,11 +22,12 @@
 	 *
 	 *--------------------------------------------------------------*/
 
+
 #include "tlf.h"
-#include "printcall.h"
-#include <curses.h>
+#include "tlf_curses.h"
 #include "ui_utils.h"
 
+
 void printcall(void)
 {
     extern char hiscall[];
