@@ -77,7 +77,6 @@ typedef struct {
   int attr;		// meta attr: 0 => not nopied, 1 => copied
 } t_qtc_ry_line;
 
-extern int nr_qsoflags_for_qtc;		// number of lines in qsoflags_for_qtc[]
 extern int next_qtc_qso;		// the next non-sent QSO, which can
 					// be send next as QTC
 extern int qsoflags_for_qtc[MAX_QSOS];	// array of flag to log lines of QSOs
@@ -112,4 +111,5 @@ extern char qtc_phsend_message[14][80];
 extern char qtc_cap_calls[40];
 extern int qtc_auto_filltime;		// set QTC auto filltime; when DX sent first
 					// QTC line, the first two digits will be copied to others
+extern int qtc_recv_lazy;		// ignore check of received QTC lines
 #endif /* end of include guard: QTCVARS_H */
