@@ -37,6 +37,7 @@
 #include "tlf_curses.h"
 #include "ui_utils.h"
 
+#include "fldigixmlrpc.h"
 
 static int fdcont;		// global for this file: tty file descriptor
 static char ry_term[5][50] = { "", "", "", "", "" };
@@ -45,7 +46,7 @@ static char ry_term[5][50] = { "", "", "", "", "" };
 int init_controller()
 {
     extern char controllerport[];
-    extern int keyerport;
+    extern int digikeyer;
 
     struct termios termattribs;
 
@@ -70,7 +71,7 @@ int init_controller()
 
     tcsetattr(fdcont, TCSANOW, &termattribs);	/* Set the serial port */
 
-    if (keyerport == GMFSK) {
+    if (digikeyer == GMFSK) {
 	lseek(fdcont, 0, SEEK_END);
     }
 
@@ -179,12 +180,11 @@ void ry_addchar(char c)
 
 int show_rtty(void)
 {
-    extern int trxmode;
     extern int miniterm;
     extern int commentfield;
     extern char comment[];
 
-    if (trxmode != DIGIMODE || miniterm == 0)
+    if (miniterm == 0)
 	return (-1);
 
     attroff(A_STANDOUT);
@@ -216,7 +216,7 @@ int show_rtty(void)
 int rx_rtty()
 {
     extern int miniterm;
-    extern int keyerport;
+    extern int digikeyer;
 
     int i;
     int j;
@@ -245,7 +245,7 @@ int rx_rtty()
 	if (i == 0)
 	    return 0;
 
-	if (keyerport == GMFSK) {
+	if (digikeyer == GMFSK) {
 	    /* skip begin of line until '):' if keyer == GMFSK */
 	    /* RX (2006-03-31 14:41Z): */
 	    for (j = 0; j < i; j++) {
@@ -286,6 +286,12 @@ int rx_rtty()
 	    }
 	}
     }
+    else if (digikeyer == FLDIGI) {
+	i = fldigi_get_rx_text(line);
+	for (j = 0; j < i; j++) {
+	    ry_addchar( line[j] );
+	}
+    }
 
     return (0);
 }
