@@ -22,9 +22,12 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "searchcallarray.h"
+
+#include <string.h>
+
 #include "tlf.h"
 
+
 /**	\brief lookup 'hiscall' in array of worked stations
  *
  * 	See if 'hiscall' was already worked by looking it up in worked[]
