@@ -22,12 +22,14 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "nicebox.h"
+
+#include <stdlib.h>
+
+#include "netkeyer.h"
+#include "nicebox.h"	// Includes curses.h
 #include "set_tone.h"
 #include "tlf.h"
-#include "cwkeyer.h"
-#include "clear_display.h"
-#include "netkeyer.h"
+
 
 int set_tone(void)
 {
