@@ -1,6 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ *               2016           Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +22,7 @@
 /* Uses ncurses, so hopefully compatible with much */
 /* dave brown n2rjt (dcb@vectorbd.com) wrote most of this */
 /* TLF integration and TNC interface by PA0RCT   07/30/2002 */
+/* Adaption to ncurses 6 by DL1JBE 2016 */
 
 
 #define VERSIONSPLIT "V1.4.1 5/18/96 - N2RJT"
@@ -41,14 +43,29 @@
 #include "splitscreen.h"
 #include "sockserv.h"
 #include "tlf_curses.h"
+#include "tlf_panel.h"
 #include "ui_utils.h"
 
+struct tln_logline {
+    struct tln_logline *next;
+    struct tln_logline *prev;
+    char *text;
+    int attr;
+} ;
+
 
 pthread_mutex_t spot_ptr_mutex = PTHREAD_MUTEX_INITIALIZER;
 
+int prsock = 0;
+int fdFIFO = 0;
+
+WINDOW *sclwin, *entwin;
+static int initialized = 0;
+
+int in_packetclient;
+
 int currow;
 int curcol;
-int maxtln_loglines = DEFAULTTLN_LOGLINES;
 int attr[3];
 int color[3][2];
 int curattr = 0;
@@ -57,7 +74,11 @@ char outbuffer[82];
 char lanflag;
 int lanspotflg = 0;
 
+int maxtln_loglines = DEFAULTTLN_LOGLINES;
 int tln_loglines = 0;
+struct tln_logline *loghead = NULL;
+struct tln_logline *logtail = NULL;
+struct tln_logline *viewing = NULL;
 
 int view_state = STATE_EDITING;
 char tln_input_buffer[2 * BUFFERSIZE];
@@ -65,9 +86,6 @@ char tln_input_buffer[2 * BUFFERSIZE];
 void addlog(char *s)
 {
     extern char lastwwv[];
-    extern struct tln_logline *loghead;
-    extern struct tln_logline *logtail;
-    extern struct tln_logline *viewing;
     extern char spot_ptr[MAX_SPOTS][82];
     extern char lastmsg[];
     extern int nr_of_spots;
@@ -151,8 +169,6 @@ void addlog(char *s)
 
 int logattr(void)
 {
-    extern struct tln_logline *viewing;
-
     if (!viewing)
 	return 0;
     else
@@ -161,9 +177,6 @@ int logattr(void)
 
 char *firstlog(void)
 {
-    extern struct tln_logline *loghead;
-    extern struct tln_logline *viewing;
-
     viewing = loghead;
     view_state = STATE_VIEWING;
     return viewing->text;
@@ -171,9 +184,6 @@ char *firstlog(void)
 
 char *lastlog(void)
 {
-    extern struct tln_logline *logtail;
-    extern struct tln_logline *viewing;
-
     viewing = logtail;
     view_state = STATE_VIEWING;
     return viewing->text;
@@ -181,10 +191,6 @@ char *lastlog(void)
 
 char *nextlog(void)
 {
-    extern struct tln_logline *loghead;
-    extern struct tln_logline *logtail;
-    extern struct tln_logline *viewing;
-
     if (view_state == STATE_EDITING)
 	viewing = loghead;
     else if (viewing)
@@ -200,10 +206,6 @@ char *nextlog(void)
 
 char *prevlog(void)
 {
-    extern struct tln_logline *loghead;
-    extern struct tln_logline *logtail;
-    extern struct tln_logline *viewing;
-
     if (view_state == STATE_EDITING)
 	viewing = logtail;
     else if (viewing)
@@ -219,9 +221,6 @@ char *prevlog(void)
 
 void start_editing(void)
 {
-    extern struct tln_logline *viewing;
-    extern WINDOW *entwin;
-
     werase(entwin);
     currow = curcol = 0;
     viewing = NULL;
@@ -230,8 +229,6 @@ void start_editing(void)
 
 void delete_prev_char(void)
 {
-    extern WINDOW *entwin;
-
     int i, j;
     int c, cc;
     if (currow != 0 || curcol != 0) {
@@ -256,8 +253,6 @@ void delete_prev_char(void)
 
 void right_arrow(void)
 {
-    extern WINDOW *entwin;
-
     if (++curcol >= COLS) {
 	curcol = 0;
 	if (++currow >= ENTRYROWS) {
@@ -270,8 +265,6 @@ void right_arrow(void)
 
 void left_arrow(void)
 {
-    extern WINDOW *entwin;
-
     if (--curcol < 0) {
 	curcol = COLS - 1;
 	if (--currow < 0) {
@@ -283,8 +276,6 @@ void left_arrow(void)
 
 void move_eol(void)
 {
-    extern WINDOW *entwin;
-
     currow = ENTRYROWS - 1;
     curcol = COLS - 1;
     while ((A_CHARTEXT & mvwinch(entwin, currow, curcol)) == ' ') {
@@ -303,7 +294,6 @@ void move_eol(void)
 
 void gather_input(char *s)
 {
-    extern WINDOW *entwin;
     int l = 0;
     int i, j;
     for (i = j = 0; i < ENTRYROWS && j < 81; j++) {
@@ -356,8 +346,6 @@ int walkdn(void)
 
 int pageup(int lines)
 {
-    extern WINDOW *sclwin;
-
     int i;
     char *s = NULL;
     walkup();
@@ -378,8 +366,6 @@ int pageup(int lines)
 
 int pagedn(int lines)
 {
-    extern WINDOW *sclwin;
-
     int i;
     char *s = NULL;
     walkdn();
@@ -401,8 +387,6 @@ char entry_text[BUFFERSIZE];
 
 void viewbottom(void)
 {
-    extern WINDOW *sclwin;
-
     int i;
     char *s;
 
@@ -431,8 +415,6 @@ void viewbottom(void)
 
 void viewtop(void)
 {
-    extern WINDOW *sclwin;
-
     int i;
     char *s;
 
@@ -453,10 +435,6 @@ void viewtop(void)
 
 void resume_editing(void)
 {
-    extern WINDOW *entwin;
-    extern WINDOW *sclwin;
-    extern struct tln_logline *viewing;
-
     viewbottom();
     wattrset(sclwin, curattr);
     werase(entwin);
@@ -469,9 +447,6 @@ void resume_editing(void)
 
 void viewlog(void)
 {
-    extern WINDOW *entwin;
-    extern struct tln_logline *viewing;
-
     attop = FALSE;
     if (walkup()) {
 	view_state = STATE_EDITING;
@@ -487,9 +462,6 @@ void viewlog(void)
 int litflag = FALSE;
 int edit_line(int c)
 {
-    extern WINDOW *entwin;
-    extern WINDOW *sclwin;
-
     if (view_state != STATE_EDITING) {
 	if (c == '\n')
 	    resume_editing();
@@ -591,8 +563,6 @@ void sanitize(char *s)
 
 void addtext(char *s)
 {
-    extern WINDOW *sclwin;
-    extern int in_packetclient;
     extern int lan_active;
     extern char call[];
     extern char hiscall[];
@@ -612,7 +582,7 @@ void addtext(char *s)
     int i, l;
 
     l = strlen(tln_input_buffer);
-    if (view_state == STATE_EDITING) {
+    if (initialized != 0 && view_state == STATE_EDITING) {
 
 	if (s[0] == '<' && s[1] != '<') {	// must be convers
 	    for (ci = 0; ci <= cl; ci++) {
@@ -653,8 +623,8 @@ void addtext(char *s)
 	if (in_packetclient == 1)
 	    wrefresh(sclwin);
     }
-// Cluster private spotting interface
 
+    // Cluster private spotting interface
     if (strncmp(s, call, strlen(call) - 1) == 0
 	&& strlen(s) < 81 && strchr(s, '>') == NULL) {
 
@@ -724,7 +694,7 @@ void addtext(char *s)
 	}
 
     }
-// end cluster private spotting interface
+    // end cluster private spotting interface
 
     for (i = 0; i < strlen(s); i++) {
 	if (s[i] == '\n' || i + l + 1 >= COLS) {
@@ -762,19 +732,16 @@ void addtext(char *s)
 =             This initializes the packet windows
 =
 ===========================================*/
+WINDOW *packet_win;
+PANEL  *packet_panel;
 
 int init_packet(void)
 {
-    extern int prsock;
     extern int portnum;
     extern char pr_hostaddress[];
-    extern SCREEN *packetscreen;
-    extern WINDOW *sclwin;
-    extern WINDOW *entwin;
     extern char spot_ptr[MAX_SPOTS][82];
     extern int tncport;
     extern int fdSertnc;
-    extern int fdFIFO;
     extern int packetinterface;
     extern int tnc_serial_rate;
     extern int verbose;
@@ -785,7 +752,6 @@ int init_packet(void)
     int addrarg;
     int iptr = 0;
     mode_t mode = 0666;
-    static int initialized = 0;
 
     tln_input_buffer[0] = '\0';
     attr[NORMAL_ATTR] = A_NORMAL;
@@ -796,15 +762,19 @@ int init_packet(void)
 
     if (initialized == 0) {
 
-	initialized = 1;
-	packetscreen = newterm(NULL, stdout, stdin);
+	packet_win = newwin(LINES,COLS,0,0);
+	packet_panel = new_panel(packet_win);
+	show_panel(packet_panel);
+	refreshp();
+
 	start_color();
 
 	/* change color settings only if we got a new screen
 	 * (there is a bug in ncurses-5.8 and 5.9 if using --enable-sp-funcs
 	 * which results in a NULL pointer )
 	 */
-	if (packetscreen) {
+#if 0
+	if (initialized) {
 	    init_pair(0, 0, 0);
 	    init_pair(1, 1, 0);
 	    init_pair(2, 2, 0);
@@ -814,8 +784,9 @@ int init_packet(void)
 	    init_pair(6, 6, 0);
 	    init_pair(7, 7, 0);
 	}
-	sclwin = newwin(LINES - ENTRYROWS, COLS, 0, 0);
-	entwin = newwin(ENTRYROWS, COLS, LINES - ENTRYROWS, 0);
+#endif
+	sclwin = derwin(packet_win, LINES - ENTRYROWS, COLS, 0, 0);
+	entwin = derwin(packet_win, ENTRYROWS, COLS, LINES - ENTRYROWS, 0);
 	scrollok(sclwin, TRUE);
 	scrollok(entwin, FALSE);
 	keypad(entwin, TRUE);
@@ -823,6 +794,8 @@ int init_packet(void)
 	wattrset(sclwin, attr[NORMAL_ATTR]);
 	wattrset(entwin, attr[ENTRY_ATTR]);
 
+	initialized = 1;
+
 	noecho();
 	cbreak();
 	wtimeout(entwin, 30);
@@ -978,28 +951,10 @@ int init_packet(void)
 int cleanup_telnet(void)
 {
 
-    extern int prsock;
-    extern WINDOW *entwin;
-    extern WINDOW *sclwin;
-    extern SCREEN *mainscreen;
     extern int packetinterface;
     extern int fdSertnc;
-    extern int fdFIFO;
 
     if (packetinterface == TELNET_INTERFACE) {
-
-	wattrset(entwin, A_NORMAL);
-	wclear(entwin);
-	wmove(entwin, 1, 0);
-	wrefresh(entwin);
-	vidattr(A_NORMAL);
-	delwin(entwin);
-	wclear(sclwin);
-	wrefresh(sclwin);
-	delwin(sclwin);
-
-	endwin();
-
 	if (prsock > 0)
 	    close_s(prsock);
 
@@ -1016,7 +971,14 @@ int cleanup_telnet(void)
 	remove("./clfile");
     }
 
-    set_term(mainscreen);
+    hide_panel(packet_panel);
+    delwin(entwin);
+    delwin(sclwin);
+    del_panel(packet_panel);
+    delwin(packet_win);
+
+    initialized = 0;
+
     clear();
     clear_display();
     keypad(stdscr, TRUE);
@@ -1034,15 +996,8 @@ int cleanup_telnet(void)
 int packet()
 {
 
-    extern SCREEN *mainscreen;
-    extern SCREEN *packetscreen;
-    extern WINDOW *sclwin;
-    extern WINDOW *entwin;
-    extern int prsock;
     extern int fdSertnc;
-    extern int fdFIFO;
     extern int packetinterface;
-    extern int in_packetclient;
     extern char clusterlogin[];
 
     char line[BUFFERSIZE];
@@ -1054,12 +1009,12 @@ int packet()
     in_packetclient = 1;
     sleep(1);
 
-    if (packetscreen) {
-    	set_term(packetscreen);
-    }
+    show_panel(packet_panel);
+
+    wrefresh(sclwin);
 
-    wclear(sclwin);
     wclear(entwin);
+    wrefresh(entwin);
 
     count = 0;
 
@@ -1071,8 +1026,9 @@ int packet()
 	    sent_login = 1;
 	    addtext("logged into cluster...\n\n");
 	    sleep(1);
-	    endwin();
-	    set_term(mainscreen);
+
+	    hide_panel(packet_panel);
+
 	    clear();
 	    clear_display();
 	    keypad(stdscr, TRUE);
@@ -1183,8 +1139,9 @@ int packet()
 	    start_editing();
 	}
     }
-    endwin();
-    set_term(mainscreen);
+
+    hide_panel(packet_panel);
+
     clear();
     clear_display();
     keypad(stdscr, TRUE);
@@ -1203,12 +1160,8 @@ int packet()
 
 int receive_packet(void)
 {
-
-    extern int prsock;
     extern int packetinterface;
     extern int fdSertnc;
-    extern int fdFIFO;
-    extern int in_packetclient;
 
     char line[BUFFERSIZE];
     int i = 0;
@@ -1275,7 +1228,6 @@ int send_cluster(void)
 {
     extern int fdSertnc;
     extern int packetinterface;
-    extern int prsock;
     extern int cluster;
 
     char line[MAX_CMD_LEN+2] = "";
