@@ -27,19 +27,20 @@
 #include "tlf.h"
 #include "tlf_curses.h"
 
+#include "fldigixmlrpc.h"
 
 int stoptx(void)
 {
   	extern int trxmode;
-  	extern int keyerport;
+  	extern int cwkeyer;
+	extern int digikeyer;
 
 
- 	if (trxmode != CWMODE){
- 		return(1);
+	if (digikeyer == FLDIGI && trxmode == DIGIMODE) {
+	    fldigi_to_rx();
  	}
-
-
-	if (keyerport == NET_KEYER) {
+	else if (trxmode == CWMODE) {
+	    if (cwkeyer == NET_KEYER) {
 
 		if (netkeyer (K_ABORT, NULL) < 0) {
 
@@ -48,6 +49,10 @@ int stoptx(void)
 			clear_display();
 
 		}
+	    }
+	}
+	else {
+	    return(1);
 	}
 	return(0);
 }
