@@ -29,6 +29,7 @@
 #define ORION_KEYER 5 	/* deprecated */
 #define K2_KEYER 6 	/* deprecated */
 #define GMFSK 7
+#define FLDIGI 8
 
 #define SINGLE 0        /* single op */
 #define MULTI 1         /* multi op / single tx */
@@ -124,8 +125,15 @@ enum {
 #define EDITOR_E3 2
 #define EDITOR_MC 3
 
+#define UNIQUECALL_ALL      1
+#define UNIQUECALL_BAND     2
+
 #define LOGLINELEN (88)		/* Length of logline in logfile
 				   (including linefeed) */
+#define MINITEST_DEFAULT_PERIOD 600
+				/* ignore dupe state when MINITEST is set
+				 * and last QSO was not in actual period */
+
 /* special message numbers */
 enum {
     SP_TU_MSG = 12,
@@ -141,18 +149,10 @@ struct worked_t {
     char exchange[12]; 		/*< the last exchange */
     int band; 			/*< bitmap for worked bands */
     int country; 		/*< its country number */
+    long qsotime[3][NBANDS];	/*< last timestamp of qso in gmtime
+				  for all modes and bands */
 };
 
-#ifndef TLN_LOGLINE
-#define TLN_LOGLINE
-struct tln_logline {
-    struct tln_logline *next;
-    struct tln_logline *prev;
-    char *text;
-    int attr;
-} ;
-#endif
-
 
 #define MAXPFXNUMMULT 30
 typedef struct {
