@@ -23,8 +23,9 @@
 	 *--------------------------------------------------------------*/
 
 
-#define _XOPEN_SOURCE 500
+#ifndef _GNU_SOURCE
 #define _GNU_SOURCE
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
