@@ -21,9 +21,16 @@
 	 *
 	 *--------------------------------------------------------------*/
 
-#include "writeparas.h"
-#include "tlf.h"
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
 #include "cw_utils.h"
+#include "tlf.h"
+#include "tlf_curses.h"
+
 
 int writeparas(void)
 {
